@@ -5,7 +5,7 @@ import logging
 import os
 import time
 import urllib
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Union
 
 import filetype
 
@@ -117,12 +117,11 @@ class FullNodeAPI(BaseAPI):
         """
         # check encryption_type
         if encryption_type.lower() not in ("public", "private"):
-            raise ParamValueError(403, "encryption_type should be `public` or `private`")
+            raise ParamValueError("encryption_type should be `public` or `private`")
 
         # check consensus_type
         if consensus_type.lower() not in ("poa",):
             raise ParamValueError(
-                403,
                 "consensus_type should be `poa` or `pos` or `pow`, but only `poa` is supported now.",
             )
 
@@ -138,7 +137,7 @@ class FullNodeAPI(BaseAPI):
 
     def seed(self, group_id=None) -> Dict:
         """get the seed of a group which you've joined in."""
-        group_id = self.check_group_id_as_required(group_id)
+        group_id = self.check_group_joined_as_required(group_id)
         seed = self._get(f"/api/v1/group/{group_id}/seed")
         return seed  # utils.check_seed(seed)
 
@@ -169,6 +168,9 @@ class FullNodeAPI(BaseAPI):
         """join a group with the seed of the group"""
 
         # seed = utils.check_seed(seed)
+        # 兼容新版本 seed
+        if type(seed) == str and seed.startswith("rum://seed?"):
+            seed = {"seed": seed}
         resp = self._post(f"/api/v{v}/group/join", seed)
         return resp  # self.raise_error(resp, "Group with same GroupId existed")
 
@@ -223,34 +225,17 @@ class FullNodeAPI(BaseAPI):
         trxs = self._post(apiurl) or []
         return utils.unique_trxs(trxs)
 
-    def _send(self, activity_type=None, group_id=None, obj=None, **kwargs) -> Dict:
-        group_id = self.check_group_joined_as_required(group_id)
-        payload = NewTrx(group_id=group_id, obj=obj, activity_type=activity_type, **kwargs).__dict__
-        return self._post("/api/v1/group/content", payload)
+    def _post_trx(self, trx):
+        return self._post("/api/v1/group/content", trx)
 
     def block(self, block_id: str, group_id=None):
         """get the info of a block in a group"""
         group_id = self.check_group_id_as_required(group_id)
         return self._get(f"/api/v1/block/{group_id}/{block_id}")
 
-    def trx(self, trx_id: str, group_id=None):
-        """get trx data by trx_id"""
-        if trx_id is None:
-            return None
-
+    def get_trx(self, trx_id: str, group_id=None):
         group_id = self.check_group_id_as_required(group_id)
-        data = {}
-        trxs = self.get_group_content(trx_id=trx_id, num=1, includestarttrx=True, group_id=group_id)
-        if len(trxs) > 1:
-            raise ParamOverflowError(f"{len(trxs)} trxs got from group: <{group_id}> with trx: <{trx_id}>.")
-        elif len(trxs) == 1:
-            data = trxs[0]
-        else:
-            data = self._get(f"/api/v1/trx/{group_id}/{trx_id}")
-            logger.info(f"data is encrypted for trx: <{trx_id}> of group: <{group_id}>.")
-        if not data:
-            logger.warning(f"data is empty for trx: <{trx_id}> of group: <{group_id}>.")
-        return data
+        return self._get(f"/api/v1/trx/{group_id}/{trx_id}")
 
     def pubqueue(self, group_id=None):
         group_id = self.check_group_id_as_required(group_id)
@@ -313,7 +298,7 @@ class FullNodeAPI(BaseAPI):
 
         trx_type = utils.check_trx_type(trx_type)
         if not memo:
-            raise ParamValueError(403, "say something in param:memo")
+            raise ParamValueError("say something in param:memo")
 
         payload = {
             "group_id": group_id,
@@ -385,7 +370,7 @@ class FullNodeAPI(BaseAPI):
 
     def _list(self, mode: str, group_id=None) -> List:
         if mode not in ["allow", "deny"]:
-            raise ParamValueError(403, "mode must be one of these: allow,deny")
+            raise ParamValueError("mode must be one of these: allow,deny")
         group_id = self.check_group_id_as_required(group_id)
         return self._get(f"/api/v1/group/{group_id}/trx/{mode}list") or []
 
@@ -529,9 +514,12 @@ class FullNodeAPI(BaseAPI):
 
         如果已经是用户, 返回申请状态
         """
-        status = self.announced_user(self.pubkey)
-        if status.get("Result") == "APPROVED":
-            return status
+        try:
+            status = self.announced_user(self.pubkey)
+            if status.get("Result") == "APPROVED":
+                return status
+        except:
+            pass
         return self.announce("add", "user", "rumpy.api,announce self as user", group_id)
 
     def announce_as_producer(self, group_id=None):
@@ -574,7 +562,7 @@ class FullNodeAPI(BaseAPI):
         }
         return self._post("/api/v1/group/user", payload)
 
-    def approve_as_user(self, pubkey=None, group_id=None):
+    def approve_as_user(self, pubkey=None, group_id=None):  # TODO:这几个 用户 全选管理的方法 从语义的角落来看，挺臃肿的，待修改。
         """approve pubkey as a user of group.
 
         pubkey: 用户公钥, 如果不提供该参数, 默认将 owner 自己添加为私有组用户
@@ -590,7 +578,7 @@ class FullNodeAPI(BaseAPI):
         group_id = self.check_group_owner_as_required(group_id)
         action = action.lower()
         if action not in ("add", "remove"):
-            raise ParamValueError(403, "action should be `add` or `remove`")
+            raise ParamValueError("action should be `add` or `remove`")
         payload = {
             "producer_pubkey": pubkey,
             "group_id": group_id,
@@ -598,14 +586,22 @@ class FullNodeAPI(BaseAPI):
         }
         return self._post("/api/v1/group/producer", payload)
 
-    def update_profile(self, name=None, image=None, mixin_id=None, group_id=None):
-        """user update the profile: name, image, or wallet.
+    def _update_profile(self, trx):
+        return self._post("/api/v1/group/profile", trx)
 
-        name: nickname of user
-        image: one image, as file_path or bytes or bytes-string
-        mixin_id: one kind of wallet
+    def pubkey_to_addr(self, pubkey):
+        payload = {"encoded_pubkey": pubkey}
+        resp = self._post("/api/v1/tools/pubkeytoaddr", payload)
+        if addr := resp.get("addr"):
+            return addr
+        else:
+            raise ParamValueError(f"pubkey_to_addr failed. pubkey:{pubkey},resp: {resp}")
+
+    def ask_for_relay(self, reley_ips: List):
+        """owner in private network ask for relay servers
+
+        Args:
+            reley_ips (List): ["/ip4/10x.xx.xxx.xxx/tcp/31124/ws/p2p/16Uiu2H...uisLB""]
+        {'ok': True}
         """
-        group_id = self.check_group_joined_as_required(group_id)
-        obj = PersonObj(name=name, image=image, wallet={"wallet_id": mixin_id})
-        payload = NewTrx(activity_type="Update", group_id=group_id, obj=obj).__dict__
-        return self._post("/api/v1/group/profile", payload)
+        return self._post("/api/v1/network/relay", reley_ips)
